TableTools examples - TableTools examples

# TableTools example TableTools examples

TableTools is a plug-in for the DataTables HTML table enhancer, which adds a highly customisable button toolbar to a DataTable. Key features include:

- Copy to clipboard
- Save table data as CSV, XLS or PDF files
- Print view for clean printing
- Row selection options
- Easy use predefined buttons
- Simple customisation of buttons
- Well defined API for advanced control